<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Browse folders and images with details such as folder size and image count.">
    <meta name="keywords" content="folder viewer, image gallery, PHP directory viewer, folder size, image count">
    <meta name="author" content="Mbsmgroup">
    <title>Folder Viewer - Mbsmgroup</title>
    <link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

    <img src="picture/logo.png" alt="Mbsmgroup Logo" title="Mbsmgroup Logo" class="logo">

    <nav class="nav-menu">
        <a href="index.php" title="Go to Home">Home</a>
        <a href="https://mbsm.tn/contact-us/" title="Contact Us">Contact Us</a>
    </nav>

    <?php
    function getFolderSize($dir) {
        $cacheFile = $dir . '/cache_size.txt';
        if (file_exists($cacheFile) && (time() - filemtime($cacheFile) < 3600)) {
            return (int)file_get_contents($cacheFile);
        }

        $totalSize = 0;
        try {
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator($dir, RecursiveDirectoryIterator::SKIP_DOTS),
                RecursiveIteratorIterator::CHILD_FIRST
            );
            foreach ($files as $file) {
                $totalSize += $file->getSize();
            }
            file_put_contents($cacheFile, $totalSize);
        } catch (Exception $e) {
            error_log("Error calculating folder size: " . $e->getMessage());
        }
        return $totalSize;
    }

    function countImages($dir) {
        $cacheFile = $dir . '/cache_images.txt';
        if (file_exists($cacheFile) && (time() - filemtime($cacheFile) < 3600)) {
            return (int)file_get_contents($cacheFile);
        }

        $imageCount = 0;
        try {
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator($dir, RecursiveDirectoryIterator::SKIP_DOTS),
                RecursiveIteratorIterator::CHILD_FIRST
            );
            foreach ($files as $file) {
                if (preg_match('/\.(jpg|jpeg|png|gif)$/i', $file->getFilename())) {
                    $imageCount++;
                }
            }
            file_put_contents($cacheFile, $imageCount);
        } catch (Exception $e) {
            error_log("Error counting images: " . $e->getMessage());
        }
        return $imageCount;
    }

    function showFolderContents($dir, $search = '', $sort = 'name') {
        $folders = [];
        try {
            if ($handle = opendir($dir)) {
                while (($file = readdir($handle)) !== false) {
                    if ($file == "." || $file == "..") {
                        continue;
                    }
                    $fullPath = $dir . '/' . $file;
                    if (is_dir($fullPath)) {
                        $size = getFolderSize($fullPath);
                        $imageCount = countImages($fullPath);
                        $folders[] = [
                            'name' => $file,
                            'path' => $fullPath,
                            'size' => $size,
                            'images' => $imageCount
                        ];
                    }
                }
                closedir($handle);
            }
        } catch (Exception $e) {
            echo "<div class='error'>Error reading directory: " . htmlspecialchars($e->getMessage()) . "</div>";
            return;
        }

        if ($search) {
            $folders = array_filter($folders, function($folder) use ($search) {
                return stripos($folder['name'], $search) !== false;
            });
        }

        usort($folders, function($a, $b) use ($sort) {
            if ($sort == 'size') {
                return $a['size'] <=> $b['size'];
            } elseif ($sort == 'images') {
                return $a['images'] <=> $b['images'];
            } else {
                return strnatcasecmp($a['name'], $b['name']);
            }
        });

        if (empty($folders)) {
            echo "<div class='warning'>No folders found matching your search criteria.</div>";
        } else {
            foreach ($folders as $folder) {
                echo "<div class='folder'>";
                echo "<a href='?folder=" . urlencode($folder['path']) . "' title='View folder: " . htmlspecialchars($folder['name']) . "'><img src='picture/folder.png' alt='Folder Icon' title='Folder Icon'></a>";
                echo "<div class='folder-name'><a href='?folder=" . urlencode($folder['path']) . "' title='View folder: " . htmlspecialchars($folder['name']) . "'>{$folder['name']}</a></div>";
                echo "<div class='folder-info'>Size: " . formatBytes($folder['size']) . " | Images: {$folder['images']}</div>";
                echo "</div>";
            }
        }
    }

    function formatBytes($bytes, $precision = 2) {
        $units = ['B', 'KB', 'MB', 'GB', 'TB'];
        $bytes = max($bytes, 0);
        $pow = floor(($bytes ? log($bytes) : 0) / log(1024));
        $bytes /= pow(1024, $pow);
        return round($bytes, $precision) . ' ' . $units[$pow];
    }

    function showImagesInFolder($folderPath, $page = 1, $search = '') {
        $imagesPerPage = 12;
        $startIndex = ($page - 1) * $imagesPerPage;
        $files = [];

        try {
            if (is_dir($folderPath)) {
                $iterator = new RecursiveIteratorIterator(
                    new RecursiveDirectoryIterator($folderPath, RecursiveDirectoryIterator::SKIP_DOTS),
                    RecursiveIteratorIterator::CHILD_FIRST
                );
                foreach ($iterator as $file) {
                    if (preg_match('/\.(jpg|jpeg|png|gif)$/i', $file->getFilename())) {
                        if ($search && stripos($file->getFilename(), $search) === false) {
                            continue;
                        }
                        $files[] = $file;
                    }
                }

                $totalImages = count($files);
                $totalPages = ceil($totalImages / $imagesPerPage);
                $files = array_slice($files, $startIndex, $imagesPerPage);

                if (empty($files)) {
                    echo "<div class='warning'>No images found matching your search criteria.</div>";
                } else {
                    echo "<div class='gallery'>";
                    foreach ($files as $file) {
                        echo "<div class='image-item'>";
                        echo "<a href='?image=" . urlencode($file->getPathname()) . "' title='View image: " . htmlspecialchars($file->getFilename()) . "'><img src='" . $file->getPathname() . "' alt='" . htmlspecialchars($file->getFilename()) . "' title='" . htmlspecialchars($file->getFilename()) . "'></a>";
                        echo "<div class='tooltip'>{$file->getFilename()}</div>";
                        echo "</div>";
                    }
                    echo "</div>";

                    echo "<div class='pagination'>";
                    for ($i = 1; $i <= $totalPages; $i++) {
                        echo "<a href='?folder=" . urlencode($folderPath) . "&page=$i&search=$search' " . ($i == $page ? "class='active'" : "") . " title='Go to page $i'>$i</a>";
                    }
                    echo "</div>";
                }
            } else {
                echo "<div class='error'>Folder not found.</div>";
            }
        } catch (Exception $e) {
            echo "<div class='error'>Error reading images: " . htmlspecialchars($e->getMessage()) . "</div>";
        }
    }

    function getImageDetails($imagePath) {
        $details = [];
        try {
            if (file_exists($imagePath)) {
                $details['title'] = pathinfo($imagePath, PATHINFO_FILENAME);
                $details['size'] = filesize($imagePath);
                $details['date'] = date("F d, Y", filemtime($imagePath));
                $details['copyright'] = "© 2025 Mbsmgroup. All rights reserved.";
                $details['owner'] = "Mbsmgroup";
                $details['description'] = "No description available.";
            } else {
                throw new Exception("Image not found.");
            }
        } catch (Exception $e) {
            echo "<div class='error'>Error retrieving image details: " . htmlspecialchars($e->getMessage()) . "</div>";
        }
        return $details;
    }

    $imagePath = isset($_GET['image']) ? urldecode($_GET['image']) : '';
    $folderPath = isset($_GET['folder']) ? urldecode($_GET['folder']) : '';
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1;
    $search = isset($_GET['search']) ? htmlspecialchars($_GET['search']) : '';

    if ($imagePath) {
        $imageDetails = getImageDetails($imagePath);
        echo "<div class='image-container'>";
        echo "<img src='" . htmlspecialchars($imagePath) . "' alt='" . htmlspecialchars($imageDetails['title']) . "' title='" . htmlspecialchars($imageDetails['title']) . "'>";
        echo "</div>";
        echo "<div class='image-details'>";
        echo "<p><strong>Title:</strong> " . htmlspecialchars($imageDetails['title']) . "</p>";
        echo "<div class='image-link'>";
        echo "<span>https://www.mbsm.tn/picture/" . htmlspecialchars($imagePath) . "</span>";
        echo "<button class='copy-button' onclick='copyToClipboard(\"https://www.mbsm.tn/picture/" . htmlspecialchars($imagePath) . "\")'>Copy</button>";
        echo "</div>";
        echo "<p><strong>Size:</strong> " . formatBytes($imageDetails['size']) . "</p>";
        echo "<p><strong>Date:</strong> " . htmlspecialchars($imageDetails['date']) . "</p>";
        echo "<p><strong>Copyright:</strong> " . htmlspecialchars($imageDetails['copyright']) . "</p>";
        echo "</div>";
    } elseif ($folderPath) {
        echo "<div class='search-bar'>";
        echo "<form method='GET' action=''>";
        echo "<input type='hidden' name='folder' value='" . htmlspecialchars(urlencode($folderPath)) . "'>";
        echo "<input type='text' name='search' placeholder='Search images...' value='$search'>";
        echo "<button type='submit' title='Search images'>Search</button>";
        echo "</form>";
        echo "</div>";
        showImagesInFolder($folderPath, $page, $search);
    } else {
        $sort = isset($_GET['sort']) ? htmlspecialchars($_GET['sort']) : 'name';
        echo "<div class='search-bar'>";
        echo "<form method='GET' action=''>";
        echo "<input type='text' name='search' placeholder='Search folders...' value='$search'>";
        echo "<select name='sort'>";
        echo "<option value='name' " . ($sort == 'name' ? 'selected' : '') . ">Sort by Name</option>";
        echo "<option value='size' " . ($sort == 'size' ? 'selected' : '') . ">Sort by Size</option>";
        echo "<option value='images' " . ($sort == 'images' ? 'selected' : '') . ">Sort by Image Count</option>";
        echo "</select>";
        echo "<button type='submit' title='Sort folders'>Go</button>";
        echo "</form>";
        echo "</div>";
        echo "<div class='gallery'>";
        showFolderContents('picture', $search, $sort);
        echo "</div>";
    }
    ?>

    <footer class="footer">
        &copy; 2025 Mbsmgroup. All rights reserved.
    </footer>

    <script>
        function copyToClipboard(text) {
            navigator.clipboard.writeText(text).then(function() {
                alert('Link copied to clipboard!');
            }, function(err) {
                console.error('Could not copy text: ', err);
            });
        }
    </script>

</body>
</html>
